; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
; 
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
; 

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 30

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| Super Motions |--------------------------------------------------------

[Command]
name="ROLLINGPUNCHES"
command=~D,DF,F,D,DF,F,y
time=30

[Command]
name="ROLLINGPUNCHES"
command=~D,DF,F,D,DF,F,z
time=30

[Command]
name="DOUBLESPINKICK"
command=~D,DF,F,D,DF,F,b
time=30

[Command]
name="DOUBLESPINKICK"
command=~D,DF,F,D,DF,F,c
time=30

[Command]
name = "CORKSCREW"
command =~D,DF,F,D,DF,F, a
time=30

[Command]
name = "CORKSCREW"
command =~D,DF,F,D,DF,F, b
time=30

[Command]
name = "CORKSCREW"
command =~D,DF,F,D,DF,F, c
time=30

;-| Special Motions |------------------------------------------------------


[Command]
name = "A_DYNA1"
command =~D, DF, F, x
time=30

[Command]
name = "A_DYNA2"
command =~D, DF, F, y
time=30

[Command]
name = "A_DYNA3"
command =~D, DF, F, z
time=30

[Command]
name = "SLIDEKICK"
command =~D, DF, F, a
time=15

[Command]
name = "ROLLKICK"
command =~D, DF, F, b
time=15

[Command]
name = "ROLLINGFLASHKICK"
command =~D, DF, F, c
time=15

[Command]
name = "DYNAMITE1"
command =~D, DF, F, x
time=15

[Command]
name = "DYNAMITE2"
command =~D, DF, F, y
time=15

[Command]
name = "DYNAMITE3"
command =~D, DF, F, z
time=15

[Command]
name = "BACKFLIP1"
command =~D, DB, B, a
time=15

[Command]
name = "BACKFLIP2"
command =~D, DB, B, b
time=15

[Command]
name = "BACKFLIP3"
command =~D, DB, B, c
time=15
;-| Double Tap |-----------------------------------------------------------

[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "High Jump"
command = $D, $U
time = 15

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = y+z
time = 1

[Command]
name = "recovery"
command = x+z
time = 1

[Command]
name = "recovery"
command = a+b
time = 1

[Command]
name = "recovery"
command = b+c
time = 1

[Command]
name = "recovery"
command = a+c
time = 1


[Command]
name = "guardpush"
command = x+y
time = 4

[Command]
name = "guardpush"
command = y+z
time = 4

[Command]
name = "guardpush"
command = x+z
time = 4

[Command]
name = "guardpush"
command = x+y+z
time = 4 


;-| Dir + Button |---------------------------------------------------------
[Command]
name = "back_x"
command = /$B,x
time = 1

[Command]
name = "back_y"
command = /$B,y
time = 1

[Command]
name = "back_z"
command = /$B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_x"
command = /$F,x
time = 1

[Command]
name = "fwd_y"
command = /$F,y
time = 1

[Command]
name = "fwd_z"
command = /$F,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "back_a"
command = /$B,a
time = 1

[Command]
name = "back_b"
command = /$B,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_a"
command = /$F,a
time = 1

[Command]
name = "fwd_b"
command = /$F,b
time = 1

[Command]
name = "fwd_c"
command = /$F,c
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Single Dir |------------------------------------------------------------
[Command]
name = "fwd" ;Required (do not remove)
command = $F
time = 1

[Command]
name = "downfwd"
command = $DF
time = 1

[Command]
name = "down" ;Required (do not remove)
command = $D
time = 1

[Command]
name = "downback"
command = $DB
time = 1

[Command]
name = "back" ;Required (do not remove)
command = $B
time = 1

[Command]
name = "upback"
command = $UB
time = 1

[Command]
name = "up" ;Required (do not remove)
command = $U
time = 1

[Command]
name = "upfwd"
command = $UF
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd" ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holddownfwd"
command = /$DF
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddownback"
command = /$DB
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdupback"
command = /$UB
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holdupfwd"
command = /$UF
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;SUPERS
;---------------------------------------------------------------------------
; ROLLING PUNCHES
[State -1, ROLLING PUNCHES]
type = ChangeState
value = 3000
triggerall=power>=1000
triggerall= command= "ROLLINGPUNCHES"&&power>=1000
triggerall = command!= "holddown"
trigger1 = statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=201&&movecontact
trigger4 = stateno=202&&movecontact
trigger5 = stateno=210&&movecontact
trigger6 = stateno=220&&movecontact
trigger7 = stateno=221&&movecontact
trigger8 = stateno=230&&movecontact
trigger9 = stateno=231&&movecontact
trigger10= stateno=400&&movecontact
trigger11= stateno=410&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=440&&movecontact
trigger14= stateno=450&&movecontact
trigger15= stateno=1030&&movecontact
trigger16= stateno=1040&&movecontact
trigger17= stateno=1050&&movecontact
trigger18= stateno = 5120 && time = [4, 9]

;---------------------------------------------------------------------------
; CORKSCREW KICK
[State -1, CORKSCREW KICK]
type = ChangeState
value = 3100
triggerall=power>=1000
triggerall=command!="BACKFLIP1"
triggerall=command!="BACKFLIP2"
triggerall=command!="BACKFLIP3"
triggerall = command = "CORKSCREW"&&power>=1000
triggerall = statetype!=S
trigger1 =   statetype!=C
trigger1 = pos y<=-40
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger2 = pos y<=-30
trigger3 = stateno=610&&movecontact
trigger3 = pos y<=-30
trigger4 = stateno=620&&movecontact
trigger4 = pos y<=-30
trigger5 = stateno=630&&movecontact
trigger5 = pos y<=-30
trigger6 = stateno=640&&movecontact
trigger6 = pos y<=-30
trigger7 = stateno=650&&movecontact
trigger7 = pos y<=-30
trigger8 = stateno=2000&&movecontact
trigger8 = pos y<=-40
trigger9 = stateno=2010&&movecontact
trigger9 = pos y<=-40
trigger10= stateno=2020&&movecontact
trigger10= pos y<=-40
;---------------------------------------------------------------------------
; DOUBLE SPIN KICK
[State -1, DOUBLE SPIN KICK]
type = ChangeState
value = 3200
triggerall=power>=1000
triggerall= command= "DOUBLESPINKICK"&&power>=1000
triggerall = command != "holddown"
trigger1 = statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=201&&movecontact
trigger4 = stateno=202&&movecontact
trigger5 = stateno=210&&movecontact
trigger6 = stateno=220&&movecontact
trigger7 = stateno=221&&movecontact
trigger8 = stateno=230&&movecontact
trigger9 = stateno=231&&movecontact
trigger10= stateno=400&&movecontact
trigger11= stateno=410&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=440&&movecontact
trigger14= stateno=450&&movecontact
trigger15= stateno=1030&&movecontact
trigger16= stateno=1040&&movecontact
trigger17= stateno=1050&&movecontact
trigger18= stateno = 5120 && time = [4, 9]


;-------------------------------------------------------------
; SPECIALS
;============================
;  DYNAMITE HEADBUTT
[State -1, DYNAMITE HEADBUTT]
type = ChangeState
value = 1000
triggerall= var(9)=0
triggerall=command!="DYNAMITE2"
triggerall=command!="DYNAMITE3"
triggerall=command="DYNAMITE1"
triggerall= statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=201&&movecontact
trigger4 = stateno=202&&movecontact
trigger5 = stateno=210&&movecontact
trigger6 = stateno=220&&movecontact
trigger7 = stateno=221&&movecontact
trigger7 = animelemtime(4)>=1
trigger8 = stateno=230&&movecontact
trigger9 = stateno=231&&movecontact
trigger10= stateno=400&&movecontact
trigger11= stateno=410&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=440&&movecontact
trigger14= stateno=450&&movecontact
trigger15= stateno=1030&&movecontact
trigger16= stateno=1040
trigger16= animelemtime(16)>=0&&movecontact
trigger17= stateno = 5120 && time = [4, 9]

;============================
;  DYNAMITE HEADBUTT
[State -1, DYNAMITE HEADBUTT]
type = ChangeState
value = 232
triggerall= var(9)=1
triggerall=command!="DYNAMITE2"
triggerall=command!="DYNAMITE3"
triggerall=command="DYNAMITE1"
triggerall= statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=201&&movecontact
trigger4 = stateno=202&&movecontact
trigger5 = stateno=210&&movecontact
trigger6 = stateno=220&&movecontact
trigger7 = stateno=221&&movecontact
trigger8 = stateno=230&&movecontact
trigger9 = stateno=231&&movecontact
trigger10= stateno=400&&movecontact
trigger11= stateno=410&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=440&&movecontact
trigger14= stateno=450&&movecontact
trigger15= stateno=1030&&movecontact
trigger16= stateno=1040
trigger16= animelemtime(16)>=0&&movecontact
trigger17= stateno = 5120 && time = [4, 9]


[State -1, DYNAMITE HEADBUTT]
type = ChangeState
value = 1010
triggerall=command!="DYNAMITE1"
triggerall=command!="DYNAMITE3"
triggerall=command="DYNAMITE2"
triggerall= statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=201&&movecontact
trigger4 = stateno=202&&movecontact
trigger5 = stateno=210&&movecontact
trigger6 = stateno=220&&movecontact
trigger7 = stateno=221&&movecontact
trigger7 = animelemtime(4)>=1
trigger8 = stateno=230&&movecontact
trigger9 = stateno=231&&movecontact
trigger10= stateno=400&&movecontact
trigger11= stateno=410&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=440&&movecontact
trigger14= stateno=450&&movecontact
trigger15= stateno=1030&&movecontact
trigger16= stateno=1040
trigger16= animelemtime(16)>=0&&movecontact
trigger17= stateno = 5120 && time = [4, 9]


[State -1, DYNAMITE HEADBUTT]
type = ChangeState
value = 1020
triggerall=command!="DYNAMITE1"
triggerall=command!="DYNAMITE2"
triggerall=command!="ROLLINGPUNCHES"
triggerall=command="DYNAMITE3"
triggerall= statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=201&&movecontact
trigger4 = stateno=202&&movecontact
trigger5 = stateno=210&&movecontact
trigger6 = stateno=220&&movecontact
trigger7 = stateno=221&&movecontact
trigger7 = animelemtime(4)>=1
trigger8 = stateno=230&&movecontact
trigger9 = stateno=231&&movecontact
trigger10= stateno=400&&movecontact
trigger11= stateno=410&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=440&&movecontact
trigger14= stateno=450&&movecontact
trigger15= stateno=1030&&movecontact
trigger16= stateno=1040
trigger16= animelemtime(16)>=0&&movecontact
trigger17= stateno = 5120 && time = [4, 9]

[State -1, DYNAMITE HEADBUTT]
type = ChangeState
value = 1000
triggerall= var(9)=0
triggerall = stateno= 100
triggerall=stateno=100&&command!="y"
triggerall=stateno=100&&command!="z"
trigger1 = command = "x"
trigger1 = statetype!=A
trigger1 = ctrl=1


[State -1, DYNAMITE HEADBUTT]
type = ChangeState
value = 232
triggerall= var(9)=1
triggerall = stateno= 100
triggerall=stateno=100&&command!="y"
triggerall=stateno=100&&command!="z"
trigger1 = command = "x"
trigger1 = statetype!=A
trigger1 = ctrl=1


[State -1, DYNAMITE HEADBUTT]
type = ChangeState
value = 1010
triggerall = stateno= 100
triggerall=stateno=100&&command!="x"
triggerall=stateno=100&&command!="z"
trigger1 = command = "y"
trigger1 = statetype!=A
trigger1 = ctrl=1

[State -1, DYNAMITE HEADBUTT]
type = ChangeState
value = 1020
triggerall = stateno= 100
triggerall=stateno=100&&command!="x"
triggerall=stateno=100&&command!="y"
trigger1 = command = "z"
trigger1 = statetype!=A
trigger1 = ctrl=1


;============================
;  SLIDE KICK
[State -1, SLIDE KICK]
type = ChangeState
value = 1030
triggerall=command="SLIDEKICK"
triggerall=command!="ROLLKICK"
triggerall=command!="ROLLINGFLASHKICK"
triggerall= statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=201&&movecontact
trigger4 = stateno=202&&movecontact
trigger5 = stateno=210&&movecontact
trigger6 = stateno=220&&movecontact
trigger7 = stateno=221&&movecontact
trigger8 = stateno=230&&movecontact
trigger9 = stateno=231&&movecontact
trigger10= stateno=400&&movecontact
trigger11= stateno=410&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=440&&movecontact
trigger14= stateno=450&&movecontact
trigger15= stateno = 5120 && time = [4, 9]

[State -1, SLIDE KICK]
type = ChangeState
value = 1030
triggerall = stateno= 100
triggerall=stateno=100&&command!="b"
triggerall=stateno=100&&command!="c"
trigger1 = command = "a"
trigger1 = statetype!=A
trigger1 = ctrl=1

;============================
;  ROLL KICK
[State -1, ROLL KICK]
type = ChangeState
value = 1040
triggerall=command="ROLLKICK"
triggerall= statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=201&&movecontact
trigger4 = stateno=202&&movecontact
trigger5 = stateno=210&&movecontact
trigger6 = stateno=220&&movecontact
trigger7 = stateno=221&&movecontact
trigger8 = stateno=230&&movecontact
trigger9 = stateno=231&&movecontact
trigger10= stateno=400&&movecontact
trigger11= stateno=410&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=440&&movecontact
trigger14= stateno=450&&movecontact
trigger15= stateno = 5120 && time = [4, 9]


[State -1, ROLL KICK]
type = ChangeState
value = 1040
triggerall = stateno= 100
triggerall=stateno=100&&command!="a"
triggerall=stateno=100&&command!="c"
trigger1 = command = "b"
trigger1 = statetype!=A
trigger1 = ctrl=1
;============================
;  ROLLING FLASH KICK
[State -1, ROLLING FLASH KICK]
type = ChangeState
value = 1050
triggerall=command="ROLLINGFLASHKICK"
triggerall=command!="ROLLKICK"
triggerall=command!="SLIDEKICK"
triggerall= statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=201&&movecontact
trigger4 = stateno=202&&movecontact
trigger5 = stateno=210&&movecontact
trigger6 = stateno=220&&movecontact
trigger7 = stateno=221&&movecontact
trigger8 = stateno=230&&movecontact
trigger9 = stateno=231&&movecontact
trigger10= stateno=400&&movecontact
trigger11= stateno=410&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=440&&movecontact
trigger14= stateno=450&&movecontact
trigger15= stateno=5120 && time = [4, 9]

[State -1, ROLLING FLASH KICK]
type = ChangeState
value = 1050
triggerall = stateno= 100
triggerall=stateno=100&&command!="a"
triggerall=stateno=100&&command!="b"
trigger1 = command = "c"
trigger1 = statetype!=A
trigger1 = ctrl=1
;============================
;  BACKFLIP KICK
[State -1, BACKFLIP KICK]
type = ChangeState
value = 1061
triggerall = stateno= 105
triggerall=stateno=105&&command!="b"
triggerall=stateno=105&&command!="c"
trigger1 = command = "a"
trigger1 = statetype!=A
trigger1 = ctrl=1

[State -1, BACKFLIP KICK]
type = ChangeState
value = 1061
triggerall = stateno= 105
triggerall=stateno=105&&command!="a"
triggerall=stateno=105&&command!="c"
trigger1 = command = "b"
trigger1 = statetype!=A
trigger1 = ctrl=1

[State -1, BACKFLIP KICK]
type = ChangeState
value = 1061
triggerall = stateno= 105
triggerall=stateno=105&&command!="a"
triggerall=stateno=105&&command!="b"
trigger1 = command = "c"
trigger1 = statetype!=A
trigger1 = ctrl=1


[State -1, BACKFLIP KICK]
type = ChangeState
value = 1060
triggerall=command!="BACKFLIP2"
triggerall=command!="BACKFLIP3"
triggerall=command="BACKFLIP1"
trigger1 = statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=201&&movecontact
trigger4 = stateno=202&&movecontact
trigger5 = stateno=210&&movecontact
trigger6 = stateno=220&&movecontact
trigger7 = stateno=221&&movecontact
trigger8 = stateno=230&&movecontact
trigger9 = stateno=231&&movecontact
trigger10= stateno=400&&movecontact
trigger11= stateno=410&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=440&&movecontact
trigger14= stateno=450&&movecontact
trigger15= stateno = 5120 && time = [4, 9]

[State -1, BACKFLIP KICK]
type = ChangeState
value = 1060
triggerall=command!="BACKFLIP1"
triggerall=command!="BACKFLIP3"
triggerall=command="BACKFLIP2"
trigger1 = statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=201&&movecontact
trigger4 = stateno=202&&movecontact
trigger5 = stateno=210&&movecontact
trigger6 = stateno=220&&movecontact
trigger7 = stateno=221&&movecontact
trigger8 = stateno=230&&movecontact
trigger9 = stateno=231&&movecontact
trigger10= stateno=400&&movecontact
trigger11= stateno=410&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=440&&movecontact
trigger14= stateno=450&&movecontact
trigger15= stateno = 5120 && time = [4, 9]

[State -1, BACKFLIP KICK]
type = ChangeState
value = 1060
triggerall=command!="BACKFLIP1"
triggerall=command!="BACKFLIP2"
triggerall=command="BACKFLIP3"
trigger1 = statetype!=A
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=201&&movecontact
trigger4 = stateno=202&&movecontact
trigger5 = stateno=210&&movecontact
trigger6 = stateno=220&&movecontact
trigger7 = stateno=221&&movecontact
trigger8 = stateno=230&&movecontact
trigger9 = stateno=231&&movecontact
trigger10= stateno=400&&movecontact
trigger11= stateno=410&&movecontact
trigger12= stateno=430&&movecontact
trigger13= stateno=440&&movecontact
trigger14= stateno=450&&movecontact
trigger15= stateno = 5120 && time = [4, 9]

;---------------------------------------------------------------------------
; AERIAL DYNAMITE HEADBUTT
[State -1, AERIAL DYNAMITE HEADBUTT]
type = ChangeState
value = 2000
triggerall=command!="A_DYNA2"
triggerall=command!="A_DYNA3"
triggerall = command ="A_DYNA1"
triggerall = statetype!=S
trigger1 =   statetype!=C
trigger1 = pos y<=-30
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger2 = pos y<=-30
trigger3 = stateno=610&&movecontact
trigger3 = pos y<=-30
trigger4 = stateno=620&&movecontact
trigger4 = pos y<=-30
trigger5 = stateno=630&&movecontact
trigger5 = pos y<=-30
trigger6 = stateno=640&&movecontact
trigger6 = pos y<=-30
trigger7 = stateno=650&&movecontact
trigger7 = pos y<=-30

; AERIAL DYNAMITE HEADBUTT
[State -1, AERIAL DYNAMITE HEADBUTT]
type = ChangeState
value = 2010
triggerall=command!="A_DYNA1"
triggerall=command!="A_DYNA3"
triggerall = command ="A_DYNA2"
triggerall = statetype!=S
trigger1 =   statetype!=C
trigger1 = pos y<=-50
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger2 = pos y<=-30
trigger3 = stateno=610&&movecontact
trigger3 = pos y<=-30
trigger4 = stateno=620&&movecontact
trigger4 = pos y<=-30
trigger5 = stateno=630&&movecontact
trigger5 = pos y<=-30
trigger6 = stateno=640&&movecontact
trigger6 = pos y<=-30
trigger7 = stateno=650&&movecontact
trigger7 = pos y<=-30
; AERIAL DYNAMITE HEADBUTT
[State -1, AERIAL DYNAMITE HEADBUTT]
type = ChangeState
value = 2020
triggerall=command!="A_DYNA1"
triggerall=command!="A_DYNA2"
triggerall = command ="A_DYNA3"
triggerall = statetype!=S
trigger1 =   statetype!=C
trigger1 = pos y<=-50
trigger1 = ctrl
trigger2 = stateno=600&&movecontact
trigger2 = pos y<=-30
trigger3 = stateno=610&&movecontact
trigger3 = pos y<=-30
trigger4 = stateno=620&&movecontact
trigger4 = pos y<=-30
trigger5 = stateno=630&&movecontact
trigger5 = pos y<=-30
trigger6 = stateno=640&&movecontact
trigger6 = pos y<=-30
trigger7 = stateno=650&&movecontact
trigger7 = pos y<=-30
;===========================================================================
;---------------------------------------------------------------------------
; Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1,Wall Jump]
type = changestate
triggerall = command = "holdfwd" && StateNo != 60 && PrevStateNo != 60 && ctrl
triggerall = anim = 42 || anim = 43
trigger1 = pos y < -30 && screenpos x < 25 && facing = 1 || pos y < -30 && screenpos x > 295 && facing = -1
value = 60
;---------------------------------------------------------------------------
[State -1,Wall Jump]
type = changestate
triggerall = command = "holdback" && StateNo != 60 && PrevStateNo != 60 && ctrl
triggerall = anim = 42 || anim = 43
trigger1 = pos y < -30 && screenpos x < 35 && facing = -1 || pos y < -30 && screenpos x > 285 && facing = 1
value = 61
;--------------------------------------------------------------------------
;Guard Push
[State -1]
type = ChangeState
value = 720
triggerall = var(10) != 1&&command = "guardpush"&&statetype = S&&p2life!=0
trigger1 = stateno = [150,153]
;-------------------------------------
[State -1]
type =ChangeState
value = 725
triggerall = var(10) != 1&&command = "guardpush"&&statetype = C&&p2life!=0
trigger1 = stateno = [150,153]
;-------------------------------------
[State -1]
type =ChangeState
value = 730 
triggerall = var(10) != 1&&command = "guardpush"&&statetype = A&&p2life!=0
trigger1 = stateno = [154,155]
;---------------------------------------------------------------------------

; Throw
[State -1, Throw]
type = ChangeState
value = 800
triggerall = stateno!=[105,106]
triggerall = command = "z" || command="c"
triggerall = statetype !=A
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 20
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 20
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H
;---------------------------------------------------------------------------

; Throw
[State -1, Throw]
type = ChangeState
value = 830
triggerall = stateno!=[105,106]
triggerall = command = "y" || command = "b"
triggerall = statetype !=A; S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 20
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 20
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;---------------------------------------------------------------------------


; Throw
[State -1, Throw]
type = ChangeState
value = 840
triggerall = stateno!=[105,106]
triggerall = command = "x"|| command="a"
triggerall = statetype !=A; S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 20
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 20
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H
;===========================================================================
;---------------------------------------------------------------------------
; Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = stateno!=[100,101]
triggerall = stateno!=[105,106]
triggerall = command = "s"
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = stateno!=[105,106]
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 =stateno=430&&movecontact

;---------------------------------------------------------------------------
; Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = stateno!=[105,106]
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 =stateno=200&&movecontact
trigger3 =stateno=230&&movecontact
trigger4 =stateno=240&&movecontact&&statetype=S
trigger5 =stateno=430&&movecontact
trigger6 =stateno=440&&movecontact
;---------------------------------------------------------------------------
; Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = stateno!=[105,106]
triggerall = hitcount<=3
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=201&&movecontact
trigger4 = stateno=202&&movecontact
trigger5 = stateno=210&&movecontact
trigger6 = stateno=400&&movecontact
trigger7 = stateno=410&&movecontact
trigger8 = stateno=430&&movecontact
trigger9 = stateno=440&&movecontact

[State -1, ChangeState]
type = ChangeState
value=221
triggerall = stateno!=[105,106]
triggerall = hitcount>=4
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno=200&&movecontact
trigger3 = stateno=201&&movecontact
trigger4 = stateno=202&&movecontact
trigger5 = stateno=210&&movecontact
trigger6 = stateno=400&&movecontact
trigger7 = stateno=410&&movecontact
trigger8 = stateno=430&&movecontact
trigger9 = stateno=440&&movecontact


;---------------------------------------------------------------------------
; Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 =stateno=200&&movecontact
trigger3 =stateno=210&&movecontact
trigger4 =stateno=220&&movecontact

;---------------------------------------------------------------------------
; Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 240
triggerall= var(10)=0
triggerall = command = "b"
triggerall = !command= "holdfwd"
triggerall = !command= "holddown"
triggerall=statetype != A
triggerall=statetype != C
trigger1 = statetype = S
trigger1 = ctrl
trigger2 =stateno=200&&movecontact
trigger3 =stateno=210&&movecontact
trigger4 =stateno=220&&movecontact
trigger5 =stateno=230&&movecontact
trigger7 = stateno=250
trigger7 = animelem<=4&&movecontact
trigger8 =stateno=400&&movecontact
trigger9 =stateno=410&&movecontact
trigger10=stateno=430&&movecontact
trigger11=stateno=440&&movecontact
trigger12=stateno=1060&&movecontact&&statetype=S
;---------------------------------------------------------------------------
; Standing Medium Kick 2
[State -1, Standing Medium Kick 2]
type = ChangeState
value = 242
triggerall= var(10)=0
triggerall = command = "b"&&command="holdfwd"
triggerall = !command= "holddown"
triggerall=statetype != A
triggerall=statetype != C
trigger1 = statetype = S
trigger1 = ctrl
trigger2 =stateno=200&&movecontact
trigger3 =stateno=210&&movecontact
trigger4 =stateno=220&&movecontact
trigger5 =stateno=221&&movecontact
trigger6 =stateno=230&&movecontact
trigger7 =stateno=250
trigger7 =animelem<=4&&movecontact
trigger8 =stateno=400&&movecontact
trigger9 =stateno=410&&movecontact
trigger10=stateno=430&&movecontact
trigger11=stateno=440&&movecontact
trigger12=stateno=1060&&movecontact&&statetype=S
;---------------------------------------------------------------------------
; Standing Medium Kick 2
[State -1, Standing Medium Kick 2]
type = ChangeState
value = 242
triggerall= var(10)>=1
triggerall = command = "b"
triggerall = !command= "holddown"
triggerall=statetype != A
triggerall=statetype != C
trigger1 = statetype = S
trigger1 = ctrl
trigger2 =stateno=200&&movecontact
trigger3 =stateno=210&&movecontact
trigger4 =stateno=220&&movecontact
trigger5 =stateno=221&&movecontact
trigger6 =stateno=230&&movecontact
trigger7 =stateno=250
trigger7 =animelem<=4&&movecontact
trigger8 =stateno=400&&movecontact
trigger9 =stateno=410&&movecontact
trigger10=stateno=430&&movecontact
trigger11=stateno=440&&movecontact
trigger12=stateno=1060&&movecontact&&statetype=S
;------------------------------------------------------------------------------
; Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 =stateno=200&&movecontact
trigger3 =stateno=210&&movecontact
trigger4 =stateno=220&&movecontact
trigger5 =stateno=230&&movecontact
trigger6 =stateno=231&&movecontact
trigger7 =stateno=240&&movecontact&&statetype=S
trigger8 = stateno=400&&movecontact
trigger9 = stateno=410&&movecontact
trigger10= stateno=430&&movecontact
trigger11= stateno=440&&movecontact
trigger12= stateno=450&&movecontact

;---------------------------------------------------------------------------
; Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = stateno!=[105,106]
triggerall = command = "x"
triggerall = command = "holddown"
;triggerall= command!= "DYNAMITE1"
triggerall=statetype!=A
trigger1 = statetype = C
trigger1 = ctrl
trigger2 =stateno=200&&movecontact
trigger3 =stateno=201&&movecontact
trigger4 =stateno=202&&movecontact
trigger5 =stateno=210&&movecontact
trigger6 =stateno=231&&movecontact
trigger7 =stateno=220&&movecontact
trigger8 =stateno=230&&movecontact
trigger9 =stateno=240&&movecontact&&statetype=S
trigger10= stateno=250
trigger10= animelem=4&&movecontact
trigger11=stateno=400&&movecontact
trigger12=stateno=430&&movecontact
trigger13=stateno=440&&movecontact


;---------------------------------------------------------------------------
; Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = stateno!=[105,106]
triggerall = command = "y"
triggerall = command = "holddown"
;triggerall=command!="DYNAMITE2"
triggerall=statetype!=A
trigger1 = statetype =C
trigger1 = ctrl
trigger2 =stateno=200&&movecontact
trigger3 =stateno=201&&movecontact
trigger4 =stateno=202&&movecontact
trigger5 =stateno=210&&movecontact
trigger6 =stateno=231&&movecontact
trigger7 =stateno=220&&movecontact
trigger8 =stateno=230&&movecontact
trigger9 =stateno=240&&movecontact&&statetype=S
trigger10= stateno=250
trigger10= animelem=4&&movecontact
trigger11=stateno=400&&movecontact
trigger12=stateno=430&&movecontact
trigger13=stateno=440&&movecontact
;---------------------------------------------------------------------------
; Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = stateno!=[105,106]
triggerall = command = "z"
triggerall = command = "holddown"
;triggerall=command!="DYNAMITE3"
triggerall=statetype!= A
trigger1 = statetype = C
trigger1 = ctrl
trigger2 =stateno=200&&movecontact
trigger3 =stateno=201&&movecontact
trigger4 =stateno=202&&movecontact
trigger5 =stateno=210&&movecontact
trigger6 =stateno=231&&movecontact
trigger7 =stateno=220&&movecontact
trigger8 =stateno=230&&movecontact
trigger9 =stateno=240&&movecontact&&statetype=S
trigger10= stateno=250
trigger10= animelem=4&&movecontact
trigger11=stateno=400&&movecontact
trigger12=stateno=410&&movecontact
trigger13=stateno=430&&movecontact
trigger14=stateno=440&&movecontact

;---------------------------------------------------------------------------
; Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = stateno!=[105,106]
triggerall = command = "a"
triggerall = command = "holddown"
triggerall=statetype!= A
trigger1 = statetype = C
trigger1 = ctrl
trigger2 =stateno=200&&movecontact
trigger3 =stateno=201&&movecontact
trigger4 =stateno=202&&movecontact
trigger5 =stateno=210&&movecontact
trigger6 =stateno=231&&movecontact
trigger7 =stateno=220&&movecontact
trigger8 =stateno=230&&movecontact
trigger9 =stateno=240&&movecontact&&statetype=S
trigger10= stateno=250
trigger10= animelem=4&&movecontact
trigger11=stateno=400&&movecontact
trigger12=stateno=410&&movecontact
trigger13=stateno=430&&movecontact
trigger14=stateno=440&&movecontact
;---------------------------------------------------------------------------
; Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = stateno!=[105,106]
triggerall = command = "b"
triggerall = command = "holddown"
triggerall=statetype!= A
trigger1 = statetype = C
trigger1 = ctrl
trigger2 =stateno=200&&movecontact
trigger3 =stateno=201&&movecontact
trigger4 =stateno=210&&movecontact
trigger5 =stateno=230&&movecontact
trigger6 =stateno=231&&movecontact
trigger7 =stateno=240&&movecontact&&statetype=S
trigger9 =stateno=250
trigger9 = animelem=4&&movecontact
trigger10=stateno=400&&movecontact
trigger11=stateno=410&&movecontact
trigger12=stateno=430&&movecontact
;---------------------------------------------------------------------------
; Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = stateno!=[105,106]
triggerall = command = "c"
triggerall = command = "holddown"
triggerall=statetype!= A
trigger1 = statetype = C
trigger1 = ctrl
trigger2 =stateno=200&&movecontact
trigger3 =stateno=201&&movecontact
trigger4 =stateno=202&&movecontact
trigger5 =stateno=210&&movecontact
trigger6 =stateno=231&&movecontact
trigger7 =stateno=220&&movecontact
trigger8 =stateno=230&&movecontact
trigger9 =stateno=240&&movecontact&&statetype=S
trigger10= stateno=250
trigger10= animelem=4&&movecontact
trigger11=stateno=400&&movecontact
trigger12=stateno=410&&movecontact
trigger13=stateno=430;&&movecontact
trigger14=stateno=440&&movecontact

;---------------------------------------------------------------------------
; Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
triggerall = statetype!=S
trigger1 = statetype = A
trigger1 = ctrl
trigger2 =stateno=630&&movecontact

;---------------------------------------------------------------------------
; Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = command = "y"
triggerall = statetype!=S
trigger1 = statetype = A
trigger1 = ctrl
trigger2 =stateno=600&&movecontact
trigger3 =stateno=630&&movecontact
trigger4 =stateno=640&&movecontact
;---------------------------------------------------------------------------
; Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = command = "z"
triggerall = statetype!=S
trigger1 = statetype = A
trigger1 = ctrl
trigger2 =stateno=600&&movecontact
trigger3 =stateno=610&&movecontact
trigger4 =stateno=630&&movecontact
trigger5 =stateno=640&&movecontact

;---------------------------------------------------------------------------
; Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
triggerall = statetype!=S
trigger1 = statetype = A
trigger1 = ctrl
trigger2 =stateno=600&&movecontact
trigger3 =stateno=610&&movecontact
;---------------------------------------------------------------------------
; Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = command = "b"
triggerall = statetype!=S
trigger1 = statetype = A
trigger1 = ctrl
trigger2 =stateno=600&&movecontact
trigger3 =stateno=610&&movecontact
trigger4 =stateno=630&&movecontact


;---------------------------------------------------------------------------
; Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = command = "c"
triggerall = statetype!=S
trigger1 = statetype = A
trigger1 = ctrl
trigger2 =stateno=600&&movecontact
trigger3 =stateno=610&&movecontact
trigger4 =stateno=620&&movecontact
trigger5 =stateno=630&&movecontact
trigger6 =stateno=640&&movecontact


;---------------------------------------------------------------------------
